@@ -18,17 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-23 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-06 Updated copyright strings
-## 2014-01-01 Fixed bug ignoring xls.nfilename
-##     ''     Simplified filename/nfilename code
-##     ''     First throw at output file type filters
-##     ''     Add ";" to suppress debug output
-## 2014-08-25 Add a little delay before terminating LO/OOo to allow
-##            zip finish low-level I/O
-## 2015-03-07 Replace deprecated strmatch
 
 function [ xls ] = __UNO_spsh_close__ (xls, force)
 
@@ -116,7 +105,7 @@ function [ xls ] = __UNO_spsh_close__ (xls, force)
     xClosbl.close (true);
     unotmp = javaObject ("com.sun.star.uno.Type", "com.sun.star.frame.XDesktop");
     xDesk = xls.app.aLoader.queryInterface (unotmp);
-    sleep (0.25);
+    pause (0.25);
     xDesk.terminate();
     xls.changed = 0;
   catch
